pub enum Error {
}Expand description
Errors that can happen during a sync with a LNURL service
Variants
InvalidLnUrl
Error decoding lnurl
InvalidLightningAddress
Error decoding lightning address
InvalidComment
Invalid LnURL pay comment
InvalidAmount
Invalid amount on request
InvalidInvoice(String)
The BOLT11 invoice returned by the callback could not be parsed
InvoiceAmountMismatch
The BOLT11 invoice amount does not match the requested amount
Fields
Ureq(Error)
Error during ureq HTTP request
Reqwest(Error)
Error during reqwest HTTP request
HttpResponse(u16)
HTTP response error
Io(Error)
IO error during ureq response read
Json(Error)
Error decoding JSON
InvalidResponse
Invalid Response
Other(String)
Other error